@@ -13,7 +13,7 @@ use base qw( FFI::C::Def );
 our @CARP_NOT = qw( FFI::C );
 
 # ABSTRACT: Array data definition for FFI
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 
 sub new
@@ -110,10 +110,20 @@ sub create
 
   local $self->{size} = $self->{size};
   my $count = $self->{members}->{count};
-  if(@_ == 1 && ! is_ref $_[0])
+  if(@_ == 1)
   {
-    $count = shift;
-    $self->{size} = $self->{members}->{member}->size * $count;
+    if(! is_ref $_[0])
+    {
+      $count = shift;
+    }
+    elsif(is_plain_arrayref $_[0])
+    {
+      $count = scalar @{$_[0]};
+    }
+    if($count)
+    {
+      $self->{size} = $self->{members}->{member}->size * $count;
+    }
   }
 
   if( (@_ == 2 && ! is_ref $_[0]) || ($self->size) )
@@ -141,7 +151,7 @@ FFI::C::ArrayDef - Array data definition for FFI
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
