@@ -5,14 +5,14 @@ use warnings;
 use 5.008001;
 use FFI::C::FFI qw( malloc memset );
 use FFI::C::Util;
-use Ref::Util qw( is_blessed_ref is_ref is_plain_hashref );
+use Ref::Util qw( is_blessed_ref is_ref is_plain_hashref is_plain_arrayref );
 use Sub::Install ();
 use Sub::Util ();
 
 our @CARP_NOT = qw( FFI::C );
 
 # ABSTRACT: Data definition for FFI
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 
 sub new
@@ -93,10 +93,20 @@ sub _generate_class
 
       my $size  = $size;
       my $count = $count;
-      if(@_ == 1 && !is_ref $_[0])
+      if(@_ == 1)
       {
-        $count = shift;
-        $size = $member_size * $count;
+        if(!is_ref $_[0])
+        {
+          $count = shift;
+        }
+        elsif(is_plain_arrayref $_[0])
+        {
+          $count = scalar @{$_[0]};
+        }
+        if($count)
+        {
+          $size = $member_size * $count;
+        }
       }
 
       if(@_ == 2 && ! is_ref $_[0])
@@ -296,7 +306,7 @@ FFI::C::Def - Data definition for FFI
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
